@@ -28,7 +28,7 @@ from kraken.common import (
 from termcolor import colored
 
 from . import __version__
-from ._buildenv import BuildEnvManager
+from ._buildenv_manager import BuildEnvManager
 from ._config import DEFAULT_CONFIG_PATH, AuthModel
 from ._lockfile import Lockfile, calculate_lockfile
 from ._option_sets import AuthOptions, EnvOptions
@@ -45,7 +45,6 @@ eprint = partial(print, file=sys.stderr)
 
 
 def _get_argument_parser() -> argparse.ArgumentParser:
-
     parser = argparse.ArgumentParser(
         "krakenw",
         formatter_class=_FormatterClass,
@@ -61,6 +60,13 @@ def _get_argument_parser() -> argparse.ArgumentParser:
             To learn more about kraken, visit https://github.com/kraken-build/kraken-core.
             """
         ),
+        epilog=inline_text(
+            colored(
+                "This is kraken-wrapper's help. To show kraken's help instead, run krakenw -- --help",
+                "yellow",
+                attrs=["bold"],
+            )
+        ),
     )
     parser.add_argument("-V", "--version", version=__version__, action="version")
     LoggingOptions.add_to_parser(parser)
@@ -75,7 +81,6 @@ def _get_argument_parser() -> argparse.ArgumentParser:
 
 
 def _get_lock_argument_parser(prog: str) -> argparse.ArgumentParser:
-
     parser = argparse.ArgumentParser(
         prog,
         formatter_class=_FormatterClass,
@@ -208,7 +213,6 @@ def _ensure_installed(
     upgrade: bool,
     env_type: EnvironmentType | None = None,
 ) -> None:
-
     exists = manager.exists()
     install = reinstall or upgrade or not exists
 
@@ -311,7 +315,7 @@ def load_project(directory: Path, outdated_check: bool = True) -> Project:
     if requirements is not None:
         eprint(
             "error: The # ::requirements header is deprecated and support for it will be removed in a future version "
-            "of kraken-wrapper. Please use the `buildscript()` function from the `kraken.commons` package "
+            "of kraken-wrapper. Please use the `buildscript()` function from the `kraken.common` package "
             "from now on.\n\n%s\n"
             % indent(runner.get_buildscript_call_recommendation(requirements.to_metadata()), "    "),
         )
